@@ -22,24 +22,24 @@ from nbxmpp.protocol import JID
 
 from gajim.common.i18n import _
 
+
 class _DEFAULT:
     pass
 
+
 class _ACCOUNT_DEFAULT:
     pass
 
+
 HAS_APP_DEFAULT = _DEFAULT()
 HAS_ACCOUNT_DEFAULT = _ACCOUNT_DEFAULT()
 
 # pylint: disable=line-too-long
 
 BoolSettings = Literal[
-    'allow_hide_roster',
-    'always_ask_for_status_message',
     'always_english_wikipedia',
     'always_english_wiktionary',
     'ascii_formatting',
-    'ask_offline_status',
     'ask_online_status',
     'autoaway',
     'autoxa',
@@ -49,10 +49,11 @@ BoolSettings = Literal[
     'command_system_execute',
     'confirm_close_muc',
     'confirm_close_multiple_tabs',
+    'confirm_on_window_delete',
     'confirm_paste_image',
     'dev_force_bookmark_2',
-    'developer_modus',
     'dev_use_message_label',
+    'developer_modus',
     'enable_negative_priority',
     'escape_key_closes',
     'gc_notify_on_all_messages_private_default',
@@ -62,28 +63,29 @@ BoolSettings = Literal[
     'hide_chat_banner',
     'hide_groupchat_banner',
     'hide_groupchat_occupants_list',
-    'hide_on_main_window_x_button',
     'ignore_incoming_attention',
-    'last_main_window_visible',
+    'is_window_visible',
     'log_contact_status_changes',
-    'main_window_skip_taskbar',
     'muc_prefer_direct_msg',
     'notification_preview_message',
     'notify_on_all_muc_messages',
     'notify_on_file_complete',
+    'plugins_auto_update',
+    'plugins_notify_after_update',
+    'plugins_repository_enabled',
+    'plugins_update_check',
     'positive_184_ack',
     'preview_allow_all_images',
     'preview_anonymous_muc',
     'preview_verify_https',
     'print_status_in_chats',
-    'quit_on_main_window_x_button',
-    'remote_commands',
     'remote_control',
     'save_main_window_position',
     'send_on_ctrl_enter',
     'shell_like_completion',
     'show_chatstate_in_banner',
     'show_help_start_chat',
+    'show_in_taskbar',
     'show_notifications',
     'show_notifications_away',
     'show_only_chat_and_online',
@@ -91,8 +93,8 @@ BoolSettings = Literal[
     'show_status_msgs_in_roster',
     'show_subject_on_join',
     'show_transports_group',
-    'show_xhtml',
     'show_trayicon',
+    'show_xhtml',
     'showoffline',
     'sort_by_show_in_muc',
     'sort_by_show_in_roster',
@@ -106,10 +108,6 @@ BoolSettings = Literal[
     'use_stun_server',
     'use_urgency_hint',
     'video_see_self',
-    'plugins_repository_enabled',
-    'plugins_update_check',
-    'plugins_auto_update',
-    'plugins_notify_after_update',
 ]
 
 IntSettings = Literal[
@@ -128,22 +126,23 @@ IntSettings = Literal[
     'mainwin_width',
     'mainwin_x_position',
     'mainwin_y_position',
-    'notification_timeout',
     'notification_position_x',
     'notification_position_y',
+    'notification_timeout',
     'preview_max_file_size',
     'preview_size',
     'restore_timeout',
 ]
 
 StringSettings = Literal[
+    'action_on_close',
     'audio_input_device',
     'audio_output_device',
     'autoaway_message',
     'autoxa_message',
     'chat_timestamp_format',
-    'date_timestamp_format',
     'confirm_block',
+    'date_timestamp_format',
     'dictionary_url',
     'emoticons_theme',
     'gc_refer_to_nick_char',
@@ -172,134 +171,130 @@ AllSettings = Literal[BoolSettings, IntSettings, StringSettings]
 AllSettingsT = Union[str, int, bool]
 
 APP_SETTINGS = {
-    'show_notifications': True,
-    'show_notifications_away': False,
-    'sounddnd': False,
-    'showoffline': True,
-    'show_only_chat_and_online': False,
-    'show_transports_group': True,
-    'autoaway': True,
-    'autoawaytime': 5,
-    'autoaway_message': '',
-    'autoxa': True,
-    'autoxatime': 15,
-    'autoxa_message': '',
-    'ask_online_status': False,
-    'ask_offline_status': False,
-    'show_trayicon': True,
-    'allow_hide_roster': False,
-    'roster_theme': 'default',
-    'sort_by_show_in_roster': True,
-    'sort_by_show_in_muc': False,
-    'use_speller': False,
-    'show_xhtml': True,
-    'speller_language': '',
-    'emoticons_theme': 'noto-emoticons',
-    'ascii_formatting': True,
-    'sounds_on': True,
-    'gc_refer_to_nick_char': ',',
-    'mainwin_x_position': 0,
-    'mainwin_y_position': 0,
-    'mainwin_width': 1000,
-    'mainwin_height': 500,
-    'save_main_window_position': True,
-    'show_main_window_on_startup': 'always',
-    'last_main_window_visible': True,
-    'quit_on_main_window_x_button': False,
-    'hide_on_main_window_x_button': False,
-    'main_window_skip_taskbar': False,
-    'latest_disco_addresses': '',
-    'change_roster_title': True,
-    'restore_timeout': -1,
-    'send_on_ctrl_enter': False,
-    'key_up_lines': 25,
-    'search_engine': 'https://duckduckgo.com/?q=%s',
-    'dictionary_url': 'WIKTIONARY',
     'always_english_wikipedia': False,
     'always_english_wiktionary': True,
-    'remote_control': False,
-    'confirm_paste_image': True,
+    'ascii_formatting': True,
+    'ask_online_status': False,
+    'audio_input_device': 'autoaudiosrc ! volume name=gajim_vol',
+    'audio_input_volume': 50,
+    'audio_output_device': 'autoaudiosink',
+    'audio_output_volume': 50,
+    'autoaway': True,
+    'autoaway_message': '',
+    'autoawaytime': 5,
+    'autoxa': True,
+    'autoxa_message': '',
+    'autoxatime': 15,
+    'change_roster_title': True,
+    'chat_handle_position': 350,
+    'chat_merge_consecutive_nickname': True,
+    'chat_timestamp_format': '%H:%M',
+    'check_for_update': True,
+    'command_system_execute': False,
+    'confirm_block': '',
     'confirm_close_muc': True,
     'confirm_close_multiple_tabs': True,
-    'notify_on_file_complete': True,
+    'confirm_on_window_delete': True,
+    'confirm_paste_image': True,
+    'dark_theme': 2,
+    'date_timestamp_format': '%x',
+    'dev_force_bookmark_2': False,
+    'dev_use_message_label': True,
+    'developer_modus': False,
+    'dictionary_url': 'WIKTIONARY',
+    'emoticons_theme': 'noto-emoticons',
+    'enable_negative_priority': False,
+    'escape_key_closes': False,
     'file_transfers_port': 28011,
     'ft_add_hosts_to_send': '',
-    'use_kib_mib': False,
-    'notify_on_all_muc_messages': False,
-    'trayicon_notification_on_events': True,
+    'gc_notify_on_all_messages_private_default': True,
+    'gc_notify_on_all_messages_public_default': False,
+    'gc_print_join_left_default': False,
+    'gc_print_status_default': False,
+    'gc_refer_to_nick_char': ',',
+    'gc_sync_threshold_private_default': 0,
+    'gc_sync_threshold_public_default': 1,
+    'global_proxy': '',
+    'groupchat_roster_width': 210,
+    'hide_chat_banner': False,
+    'hide_groupchat_banner': False,
+    'hide_groupchat_occupants_list': False,
+    'ignore_incoming_attention': False,
+    'key_up_lines': 25,
+    'is_window_visible': True,
     'last_save_dir': '',
     'last_send_dir': '',
     'last_sounds_dir': '',
-    'notification_preview_message': True,
-    'notification_position_x': -1,
-    'notification_position_y': -1,
+    'last_update_check': '',
+    'latest_disco_addresses': '',
+    'log_contact_status_changes': False,
+    'mainwin_height': 500,
+    'mainwin_width': 1000,
+    'mainwin_x_position': 0,
+    'mainwin_y_position': 0,
+    'action_on_close': 'hide',
     'muc_highlight_words': '',
     'muc_prefer_direct_msg': True,
-    'show_status_msgs_in_roster': True,
-    'print_status_in_chats': False,
-    'log_contact_status_changes': False,
-    'use_urgency_hint': True,
-    'notification_timeout': 5,
-    'escape_key_closes': False,
-    'hide_groupchat_banner': False,
-    'hide_chat_banner': False,
-    'hide_groupchat_occupants_list': False,
-    'chat_merge_consecutive_nickname': True,
-    'confirm_block': '',
-    'enable_negative_priority': False,
-    'shell_like_completion': False,
-    'audio_input_device': 'autoaudiosrc ! volume name=gajim_vol',
-    'audio_output_device': 'autoaudiosink',
-    'video_input_device': 'autovideosrc',
-    'video_framerate': '',
-    'video_size': '',
-    'video_see_self': True,
-    'audio_input_volume': 50,
-    'audio_output_volume': 50,
-    'use_stun_server': False,
-    'stun_server': '',
-    'global_proxy': '',
-    'ignore_incoming_attention': False,
-    'positive_184_ack': False,
-    'use_keyring': True,
-    'remote_commands': False,
-    'dark_theme': 2,
-    'gc_sync_threshold_public_default': 1,
-    'gc_sync_threshold_private_default': 0,
-    'show_subject_on_join': True,
-    'show_chatstate_in_banner': True,
-    'muclumbus_api_jid': 'api@search.jabber.network',
     'muclumbus_api_http_uri': 'https://search.jabber.network/api/1.0/search',
+    'muclumbus_api_jid': 'api@search.jabber.network',
     'muclumbus_api_pref': 'http',
-    'command_system_execute': False,
-    'groupchat_roster_width': 210,
-    'dev_force_bookmark_2': False,
-    'developer_modus': False,
-    'dev_use_message_label': True,
-    'use_libappindicator': True,
-    'show_help_start_chat': True,
-    'gc_notify_on_all_messages_private_default': True,
-    'gc_notify_on_all_messages_public_default': False,
-    'gc_print_status_default': False,
-    'gc_print_join_left_default': False,
-    'check_for_update': True,
-    'last_update_check': '',
-    'always_ask_for_status_message': False,
-    'show_send_message_button': False,
-    'workspace_order': [],
-    'chat_handle_position': 350,
-    'chat_timestamp_format': '%H:%M',
-    'date_timestamp_format': '%x',
-    'preview_size': 300,
-    'preview_max_file_size': 10485760,
-    'preview_allow_all_images': False,
-    'preview_leftclick_action': 'open',
-    'preview_verify_https': True,
-    'preview_anonymous_muc': False,
-    'plugins_repository_enabled': True,
-    'plugins_update_check': True,
+    'notification_position_x': -1,
+    'notification_position_y': -1,
+    'notification_preview_message': True,
+    'notification_timeout': 5,
+    'notify_on_all_muc_messages': False,
+    'notify_on_file_complete': True,
     'plugins_auto_update': False,
     'plugins_notify_after_update': True,
+    'plugins_repository_enabled': True,
+    'plugins_update_check': True,
+    'positive_184_ack': False,
+    'preview_allow_all_images': False,
+    'preview_anonymous_muc': False,
+    'preview_leftclick_action': 'open',
+    'preview_max_file_size': 10485760,
+    'preview_size': 300,
+    'preview_verify_https': True,
+    'print_status_in_chats': False,
+    'remote_control': False,
+    'restore_timeout': -1,
+    'roster_theme': 'default',
+    'save_main_window_position': True,
+    'search_engine': 'https://duckduckgo.com/?q=%s',
+    'send_on_ctrl_enter': False,
+    'shell_like_completion': False,
+    'show_chatstate_in_banner': True,
+    'show_help_start_chat': True,
+    'show_in_taskbar': True,
+    'show_main_window_on_startup': 'always',
+    'show_notifications': True,
+    'show_notifications_away': False,
+    'show_only_chat_and_online': False,
+    'show_send_message_button': False,
+    'show_status_msgs_in_roster': True,
+    'show_subject_on_join': True,
+    'show_transports_group': True,
+    'show_trayicon': True,
+    'show_xhtml': True,
+    'showoffline': True,
+    'sort_by_show_in_muc': False,
+    'sort_by_show_in_roster': True,
+    'sounddnd': False,
+    'sounds_on': True,
+    'speller_language': '',
+    'stun_server': '',
+    'trayicon_notification_on_events': True,
+    'use_keyring': True,
+    'use_kib_mib': False,
+    'use_libappindicator': True,
+    'use_speller': False,
+    'use_stun_server': False,
+    'use_urgency_hint': True,
+    'video_framerate': '',
+    'video_input_device': 'autovideosrc',
+    'video_see_self': True,
+    'video_size': '',
+    'workspace_order': [],
 }
 
 BoolAccountSettings = Literal[
@@ -385,15 +380,15 @@ AllAccountSettings = Literal[BoolAccountSettings,
 
 BoolGroupChatSettings = Literal[
     'notify_on_all_messages',
-    'print_status',
     'print_join_left',
+    'print_status',
     'send_chatstate',
     'send_marker',
 ]
 
 StringGroupChatSettings = Literal[
-    'speller_language',
     'encryption',
+    'speller_language',
 ]
 
 IntGroupChatSettings = Literal[
@@ -409,96 +404,96 @@ AllGroupChatSettingsT = Union[str, int, bool]
 
 ACCOUNT_SETTINGS = {
     'account': {
-        'name': '',
-        'account_label': '',
         'account_color': 'rgb(85, 85, 85)',
-        'hostname': '',
+        'account_label': '',
+        'active': True,
+        'adjust_priority_with_status': False,
         'anonymous_auth': False,
+        'answer_receipts': True,
+        'attached_gpg_keys': '',
+        'autoauth': False,
+        'autoconnect': False,
+        'autopriority_away': 40,
+        'autopriority_chat': 50,
+        'autopriority_dnd': 20,
+        'autopriority_online': 50,
+        'autopriority_xa': 30,
         'avatar_sha': '',
+        'chat_history_max_age': -1,
         'client_cert': '',
         'client_cert_encrypted': False,
-        'savepass': False,
-        'password': '',
-        'resource': 'gajim.$rand',
-        'priority': 0,
-        'adjust_priority_with_status': False,
-        'autopriority_online': 50,
-        'autopriority_chat': 50,
-        'autopriority_away': 40,
-        'autopriority_xa': 30,
-        'autopriority_dnd': 20,
-        'autoconnect': False,
-        'restore_last_status': False,
-        'autoauth': False,
-        'active': True,
-        'proxy': '',
-        'keyid': '',
-        'keyname': '',
-        'use_plain_connection': False,
         'confirm_unencrypted_connection': True,
-        'use_custom_host': False,
-        'custom_port': 5222,
         'custom_host': '',
+        'custom_port': 5222,
         'custom_type': 'START TLS',
-        'sync_with_global_status': False,
-        'attached_gpg_keys': '',
-        'http_auth': 'ask',
-        'file_transfer_proxies': '',
-        'use_ft_proxies': False,
-        'test_ft_proxies_on_startup': False,
-        'is_zeroconf': False,
-        'last_status': 'online',
-        'last_status_msg': '',
-        'zeroconf_first_name': '',
-        'zeroconf_last_name': '',
-        'zeroconf_jabber_id': '',
-        'zeroconf_email': '',
-        'answer_receipts': True,
-        'publish_tune': False,
-        'publish_location': False,
-        'request_user_data': True,
-        'ignore_unknown_contacts': False,
-        'send_os_info': True,
-        'send_time_info': True,
-        'send_idle_time': True,
-        'roster_version': '',
-        'subscription_request_msg': '',
-        'ft_send_local_ips': True,
-        'recent_groupchats': '',
-        'filetransfer_preference': 'httpupload',
-        'send_chatstate_default': 'composing_only',
-        'gc_send_chatstate_default': 'composing_only',
-        'send_marker_default': True,
-        'gc_send_marker_private_default': True,
-        'gc_send_marker_public_default': False,
-        'chat_history_max_age': -1,
         'enable_gssapi': False,
         'enable_security_labels': False,
+        'file_transfer_proxies': '',
+        'filetransfer_preference': 'httpupload',
+        'ft_send_local_ips': True,
+        'gc_send_chatstate_default': 'composing_only',
+        'gc_send_marker_private_default': True,
+        'gc_send_marker_public_default': False,
+        'hostname': '',
+        'http_auth': 'ask',
+        'ignore_unknown_contacts': False,
+        'is_zeroconf': False,
+        'keyid': '',
+        'keyname': '',
+        'last_status': 'online',
+        'last_status_msg': '',
+        'name': '',
+        'password': '',
+        'priority': 0,
+        'proxy': '',
+        'publish_location': False,
+        'publish_tune': False,
+        'recent_groupchats': '',
+        'request_user_data': True,
+        'resource': 'gajim.$rand',
+        'restore_last_status': False,
+        'roster_version': '',
+        'savepass': False,
+        'send_chatstate_default': 'composing_only',
+        'send_idle_time': True,
+        'send_marker_default': True,
+        'send_os_info': True,
+        'send_time_info': True,
+        'subscription_request_msg': '',
+        'sync_with_global_status': False,
+        'test_ft_proxies_on_startup': False,
+        'use_custom_host': False,
+        'use_ft_proxies': False,
+        'use_plain_connection': False,
+        'zeroconf_email': '',
+        'zeroconf_first_name': '',
+        'zeroconf_jabber_id': '',
+        'zeroconf_last_name': '',
     },
 
     'contact': {
-        'speller_language': '',
+        'encryption': '',
         'send_chatstate': HAS_ACCOUNT_DEFAULT,
         'send_marker': HAS_ACCOUNT_DEFAULT,
-        'encryption': '',
+        'speller_language': '',
     },
 
     'group_chat': {
-        'speller_language': '',
+        'encryption': '',
         'notify_on_all_messages': HAS_APP_DEFAULT,
-        'print_status': HAS_APP_DEFAULT,
         'print_join_left': HAS_APP_DEFAULT,
+        'print_status': HAS_APP_DEFAULT,
         'send_chatstate': HAS_ACCOUNT_DEFAULT,
         'send_marker': HAS_ACCOUNT_DEFAULT,
-        'encryption': '',
+        'speller_language': '',
         'sync_threshold': HAS_APP_DEFAULT,
     },
 }
 
 StringWorkspaceSettings = Literal[
-    'name',
+    'avatar_sha',
     'color',
-    'avatar_sha'
+    'name',
 ]
 
 AllWorkspaceSettings = Literal[StringWorkspaceSettings, 'open_chats']
@@ -506,6 +501,7 @@ AllWorkspaceSettings = Literal[StringWorkspaceSettings, 'open_chats']
 OpenChatSettingT = list[tuple[str, JID, str, bool]]
 AllWorkspaceSettingsT = Union[str, OpenChatSettingT]
 
+
 class WorkspaceSettings(TypedDict):
     name: str
     color: str
@@ -619,59 +615,56 @@ DEFAULT_SOUNDEVENT_SETTINGS = {
 
 ADVANCED_SETTINGS = {
     'app': {
-        'allow_hide_roster': _('Allow to hide the contact list window even if the notification area icon is not shown.'),
-        'ascii_formatting': _('Treat * / _ pairs as possible formatting characters.'),
-        'gc_refer_to_nick_char': _('Character to add after nickname when using nickname completion (tab) in group chat.'),
-        'save_main_window_position': _('If enabled, Gajim will save the main window position when hiding it, and restore it when showing the window again.'),
-        'chat_timestamp_format': 'https://docs.python.org/3/library/time.html#time.strftime',
-        'date_timestamp_format': 'https://docs.python.org/3/library/time.html#time.strftime',
-        'change_roster_title': _('If enabled, Gajim will add * and [n] in contact list window title.'),
-        'restore_timeout': _('How far back in time (minutes) chat history is restored. -1 means no limit.'),
-        'send_on_ctrl_enter': _('Send message on Ctrl+Enter and make a new line with Enter.'),
-        'key_up_lines': _('How many lines to store for Ctrl+KeyUP (previously sent messages).'),
-        'search_engine': '',
-        'dictionary_url': _('Either a custom URL with %%s in it (where %%s is the word/phrase) or \'WIKTIONARY\' (which means use Wikitionary).'),
         'always_english_wikipedia': '',
         'always_english_wiktionary': '',
-        'remote_control': _('If checked, Gajim can be controlled remotely using gajim-remote.'),
-        'confirm_paste_image': _('Ask before pasting an image.'),
+        'ascii_formatting': _('Treat * / _ pairs as possible formatting characters.'),
+        'change_roster_title': _('If enabled, Gajim will add * and [n] in contact list window title.'),
+        'chat_merge_consecutive_nickname': _('Show message meta data (avatar, nickname, timestamp) only once, if there are multiple messages from the same sender within a specific timespan.'),
+        'chat_timestamp_format': 'https://docs.python.org/3/library/time.html#time.strftime',
+        'command_system_execute': _('If enabled, Gajim will execute commands (/show, /sh, /execute, /exec).'),
+        'confirm_block': _('Show a confirmation dialog to block a contact? Empty string means never show the dialog.'),
         'confirm_close_muc': _('Ask before closing a group chat tab/window.'),
         'confirm_close_multiple_tabs': _('Ask before closing tabbed chat window if there are chats that can lose data (chat, private chat).'),
-        'file_transfers_port': '',
-        'ft_add_hosts_to_send': _('List of send hosts (comma separated) in addition to local interfaces for file transfers (in case of address translation/port forwarding).'),
-        'use_kib_mib': _('IEC standard says KiB = 1024 bytes, KB = 1000 bytes.'),
-        'notify_on_all_muc_messages': '',
-        'trayicon_notification_on_events': _('Notify of events in the notification area.'),
-        'notification_preview_message': _('Preview new messages in notification popup?'),
-        'muc_highlight_words': _('A list of words (semicolon separated) that will be highlighted in group chats.'),
-        'hide_on_main_window_x_button': _('If enabled, Gajim hides the main window when pressing the X button instead of minimizing into the notification area.'),
-        'main_window_skip_taskbar': _('Don’t show main window in the system taskbar.'),
-        'use_urgency_hint': _('If enabled, Gajim makes the window flash (the default behaviour in most Window Managers) when holding pending events.'),
-        'notification_timeout': '',
-        'escape_key_closes': _('If enabled, pressing Esc closes a tab/window.'),
-        'hide_groupchat_banner': _('Hides the banner in a group chat window.'),
-        'hide_chat_banner': _('Hides the banner in a 1:1 chat window.'),
-        'hide_groupchat_occupants_list': _('Hides the group chat participants list in a group chat window.'),
-        'chat_merge_consecutive_nickname': _('Show message meta data (avatar, nickname, timestamp) only once, if there are multiple messages from the same sender within a specific timespan.'),
-        'confirm_block': _('Show a confirmation dialog to block a contact? Empty string means never show the dialog.'),
-        'enable_negative_priority': _('If enabled, you will be able to set a negative priority to your account in the Accounts window. BE CAREFUL, when you are logged in with a negative priority, you will NOT receive any message from your server.'),
-        'shell_like_completion': _('If enabled, completion in group chats will be like a shell auto-completion.'),
-        'use_stun_server': _('If enabled, Gajim will try to use a STUN server when using Jingle. The one in \'stun_server\' option, or the one given by the XMPP server.'),
-        'stun_server': _('STUN server to use when using Jingle'),
-        'ignore_incoming_attention': _('If enabled, Gajim will ignore incoming attention requests (\'wizz\').'),
-        'remote_commands': _('If enabled, Gajim will execute XEP-0146 Commands.'),
-        'muclumbus_api_jid': '',
-        'muclumbus_api_http_uri': '',
-        'muclumbus_api_pref': _('API Preferences. Possible values: \'http\', \'iq\''),
-        'command_system_execute': _('If enabled, Gajim will execute commands (/show, /sh, /execute, /exec).'),
-        'groupchat_roster_width': _('Width of group chat roster in pixel'),
-        'gc_notify_on_all_messages_private_default': '',
-        'gc_notify_on_all_messages_public_default': '',
-        'developer_modus': '',
+        'confirm_on_window_delete': _('Ask before quitting when Gajim’s window is closed'),
+        'confirm_paste_image': _('Ask before pasting an image.'),
+        'date_timestamp_format': 'https://docs.python.org/3/library/time.html#time.strftime',
         'dev_force_bookmark_2': _('Force Bookmark 2 usage'),
         'dev_use_message_label': '',
-        'use_libappindicator': _('Enables libappindicator, an alternative tray icon provider'),
+        'developer_modus': '',
+        'dictionary_url': _('Either a custom URL with %%s in it (where %%s is the word/phrase) or \'WIKTIONARY\' (which means use Wikitionary).'),
+        'enable_negative_priority': _('If enabled, you will be able to set a negative priority to your account in the Accounts window. BE CAREFUL, when you are logged in with a negative priority, you will NOT receive any message from your server.'),
+        'escape_key_closes': _('If enabled, pressing Esc closes a tab/window.'),
+        'file_transfers_port': '',
+        'ft_add_hosts_to_send': _('List of send hosts (comma separated) in addition to local interfaces for file transfers (in case of address translation/port forwarding).'),
+        'gc_notify_on_all_messages_private_default': '',
+        'gc_notify_on_all_messages_public_default': '',
+        'gc_refer_to_nick_char': _('Character to add after nickname when using nickname completion (tab) in group chat.'),
+        'groupchat_roster_width': _('Width of group chat roster in pixel'),
+        'hide_chat_banner': _('Hides the banner in a 1:1 chat window.'),
+        'hide_groupchat_banner': _('Hides the banner in a group chat window.'),
+        'hide_groupchat_occupants_list': _('Hides the group chat participants list in a group chat window.'),
+        'ignore_incoming_attention': _('If enabled, Gajim will ignore incoming attention requests (\'wizz\').'),
+        'key_up_lines': _('How many lines to store for Ctrl+KeyUP (previously sent messages).'),
         'log_contact_status_changes': '',
+        'muc_highlight_words': _('A list of words (semicolon separated) that will be highlighted in group chats.'),
+        'muclumbus_api_http_uri': '',
+        'muclumbus_api_jid': '',
+        'muclumbus_api_pref': _('API Preferences. Possible values: \'http\', \'iq\''),
+        'notification_preview_message': _('Preview new messages in notification popup?'),
+        'notification_timeout': '',
+        'notify_on_all_muc_messages': '',
+        'plugins_repository_enabled': _('If enabled, Gajim offers to download plugins hosted on gajim.org'),
+        'restore_timeout': _('How far back in time (minutes) chat history is restored. -1 means no limit.'),
+        'save_main_window_position': _('If enabled, Gajim will save the main window position when hiding it, and restore it when showing the window again.'),
+        'search_engine': '',
+        'send_on_ctrl_enter': _('Send message on Ctrl+Enter and make a new line with Enter.'),
+        'shell_like_completion': _('If enabled, completion in group chats will be like a shell auto-completion.'),
+        'stun_server': _('STUN server to use when using Jingle'),
+        'trayicon_notification_on_events': _('Notify of events in the notification area.'),
+        'use_kib_mib': _('IEC standard says KiB = 1024 bytes, KB = 1000 bytes.'),
+        'use_libappindicator': _('Enables libappindicator, an alternative tray icon provider'),
+        'use_stun_server': _('If enabled, Gajim will try to use a STUN server when using Jingle. The one in \'stun_server\' option, or the one given by the XMPP server.'),
+        'use_urgency_hint': _('If enabled, Gajim makes the window flash (the default behaviour in most Window Managers) when holding pending events.'),
     },
 }
 
