@@ -21,6 +21,7 @@ from typing import Union
 
 import logging
 import time
+import pickle
 
 from gi.repository import Gio
 from gi.repository import Gdk
@@ -595,7 +596,7 @@ class ChatRow(Gtk.ListBoxRow):
 
         if self.contact.is_groupchat and not self.contact.can_notify():
             self._ui.unread_label.get_style_context().add_class(
-               'unread-counter-silent')
+                'unread-counter-silent')
 
         # Get last chat message from archive
         line = app.storage.archive.get_last_conversation_line(account, jid)
@@ -737,8 +738,8 @@ class ChatRow(Gtk.ListBoxRow):
                           _time: int
                           ) -> None:
         drop_type = Gdk.Atom.intern_static_string('CHAT_LIST_ITEM')
-        data = f'{self.account} {self.jid}'.encode('utf-8')
-        selection_data.set(drop_type, 32, data)
+        byte_data = pickle.dumps((self.account, self.jid))
+        selection_data.set(drop_type, 8, byte_data)
 
     def toggle_pinned(self) -> None:
         self._pinned = not self._pinned
